@@ -12,11 +12,13 @@
  * This object is a thin glib wrapper around a libusb_endpoint_descriptor.
  *
  * All the data is copied when the object is created and the original
- * descriptor can be destoyed any at point.
+ * descriptor can be destroyed any at point.
  */
 
 #include "config.h"
 
+#include <string.h>
+
 #include "gusb-endpoint.h"
 #include "gusb-endpoint-private.h"
 
